import fastapi
from fastapi.staticfiles import StaticFiles
import pydantic

from api.router import router
from db.conf import init_db
from exceptions import handlers as exc_handlers, http as http_exc


def setup():
    app = fastapi.FastAPI()
    app.include_router(router)
    
    app.exception_handler(pydantic.ValidationError)(exc_handlers.query_params_exc_handler)
    app.exception_handler(http_exc.BaseHTTPException)(exc_handlers.request_exc_handler)
    app.exception_handler(500)(exc_handlers.internal_exc_handler)
    
    app.mount('/media', StaticFiles(directory='media'), name='media')

    return app


app = setup()

init_db(app)

if __name__ == '__main__':
    import uvicorn

    uvicorn.run('main:app', host='0.0.0.0', port=1026, reload=True)
